@@ -41,12 +41,13 @@ startingValues = getStartingValues(pql=thepql, ragged=ragged)
 startingFunction(startingValues, initFile)
 
 # create the model
-spatialEffect = grep("Spatial$", names(ragged), value=T)
-#use substr to get the name of the effect 
+spatialEffect = grep("^N[[:alnum:]]+Spatial$", names(ragged), value=T)
+spatialEffect = gsub("^N", "", spatialEffect)
+spatialEffect = gsub("Spatial$", "", spatialEffect)
 
 writeBugsModel(modelFile, effects =effects,
     covariates = covariates, observations = observations,
-     family=family, spatial = effects[!is.null(spatialEffect)] ) # add spatial            
+     family=family, spatial = spatialEffect ) # add spatial            
      
 return(list(ragged=ragged, startingValues = startingValues, pql=thepql))  
 }
